@@ -1,5 +1,6 @@
 # ABSTRACT: create base(line) scan that will be used for future comparisons
 package App::Monport::Command::base;
+use strict;
 use App::Monport -command;
 use App::Monport::Nmap;
 
@@ -26,10 +27,19 @@ Options.
 =cut
 
 sub options {
-  return (
-    [ "nmapopts|o=s@", "nmap options" ],
-    [ 'nmapexe|e=s', "nmap executable (default: '/usr/bin/nmap')", { default => "/usr/bin/nmap" } ],
-  );
+    return (
+        [ "nmapopts|o=s@", "nmap options" ],
+        [
+            'nmapexe|e=s',
+            "nmap executable (default: '/usr/bin/nmap')",
+            { default => "/usr/bin/nmap" }
+        ],
+        [
+            'name|n=s',
+            "name of the scan (default: 'noname')",
+            { default => "noname" }
+        ],
+    );
 }
 
 =head2 validate()
@@ -39,9 +49,9 @@ Validate the command options and arguments.
 =cut
 
 sub validate {
-  my ($self, $opt, $args) = @_;
+    my ( $self, $opt, $args ) = @_;
 
-  $self->usage_error("no target(s) to scan") unless @$args;
+    $self->usage_error("no target(s) to scan") unless @$args;
 }
 
 =head2 execute()
@@ -51,11 +61,11 @@ Run the command.
 =cut
 
 sub execute {
-  my ($self, $opt, $args) = @_;
+    my ( $self, $opt, $args ) = @_;
 
-  set_vars($opt->name, $opt->nmapexe);
+    set_vars( $opt->name, $opt->nmapexe );
 
-  do_basescan($opt->nmapopts, $args);
+    do_basescan( $opt->nmapopts, $args );
 }
 
 1;
